==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/kvirc/ui/kvi_scriptbutton.h <==
#ifndef _KVI_SCRIPTBUTTON_H_
#define _KVI_SCRIPTBUTTON_H_
//
//   File : kvi_scriptbutton.h
//   Creation date : Wed Nov 14 15:43:39 2001 GMT by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_settings.h"
#include "kvi_string.h"

#include <qtoolbutton.h>
#include <qtoolbar.h>

class KviWindow;

class KVIRC_API KviScriptUserButton : public QToolButton
{
	Q_OBJECT
public:
	KviScriptUserButton(QWidget * par,const char * name);
	~KviScriptUserButton();
protected:
	KviStr m_szCode;
public:
	void setButtonCode(const char * code){ m_szCode = code; };
	virtual void setButtonPixmap(const QPixmap & pix){ setIconSet(pix); };
	void setButtonText(const char * text){ setTextLabel(text); };
	virtual KviWindow * window();
protected slots:
	void btnClicked();
};

class KVIRC_API KviIrcToolBarScriptButton : public KviScriptUserButton
{
	Q_OBJECT
public:
	KviIrcToolBarScriptButton(QToolBar * p,const char * name);
	~KviIrcToolBarScriptButton();
protected:
	KviStr m_szCode;
public:
	virtual KviWindow * window();
};

class KVIRC_API KviWindowScriptButton : public KviScriptUserButton
{
	Q_OBJECT
public:
	KviWindowScriptButton(QWidget * p,KviWindow * wnd,const char * name);
	~KviWindowScriptButton();
protected:
	KviWindow * m_pWnd;
public:
	virtual void setButtonPixmap(const QPixmap & pix){ setIconSet(pix); setUsesBigPixmap(false); };
	virtual KviWindow * window(){ return m_pWnd; };
};

#endif //_KVI_SCRIPTBUTTON_H_

==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/kvirc/ui/kvi_scriptbutton.h <==
#ifndef _KVI_SCRIPTBUTTON_H_
#define _KVI_SCRIPTBUTTON_H_
//
//   File : kvi_scriptbutton.h
//   Creation date : Wed Nov 14 15:43:39 2001 GMT by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_settings.h"
#include "kvi_string.h"
#include "kvi_styled_controls.h"

#include <qtoolbutton.h>
#include <qtoolbar.h>

class KviKvsScript;
class KviWindow;

class KVIRC_API KviScriptUserButton : public KviStyledToolButton
{
	Q_OBJECT
public:
	KviScriptUserButton(QWidget * par,const char * name);
	~KviScriptUserButton();
protected:
	KviKvsScript * m_pScript;
public:
	void setButtonCode(KviKvsScript * pScript);
	virtual void setButtonPixmap(const QPixmap & pix){ setIconSet(pix); };
	void setButtonText(const char * text){ setTextLabel(text); };
	virtual KviWindow * window();
protected slots:
	void btnClicked();
};

/*
class KVIRC_API KviIrcToolBarScriptButton : public KviScriptUserButton
{
	Q_OBJECT
public:
	KviIrcToolBarScriptButton(QToolBar * p,const char * name);
	~KviIrcToolBarScriptButton();
protected:
	KviStr m_szCode;
public:
	virtual KviWindow * window();
};
*/

class KVIRC_API KviWindowScriptButton : public KviScriptUserButton
{
	Q_OBJECT
public:
	KviWindowScriptButton(QWidget * p,KviWindow * wnd,const char * name);
	~KviWindowScriptButton();
protected:
	KviWindow * m_pWnd;
public:
	virtual void setButtonPixmap(const QPixmap & pix){ setIconSet(pix); setUsesBigPixmap(false); };
	virtual KviWindow * window(){ return m_pWnd; };
};

#endif //_KVI_SCRIPTBUTTON_H_
